@@ -25,7 +25,7 @@ THE SOFTWARE.
 
 import sys
 
-VERSION = (0, 6, 1)
+VERSION = (0, 6, 2)
 
 try:
     import convertresx as converters
@@ -90,27 +90,11 @@ def Connect(*args, **kwargs):
         from cymysql.connections import Connection
     return Connection(*args, **kwargs)
 
-def get_client_info():  # for MySQLdb compatibility
-  return '%s.%s.%s' % VERSION
-
 connect = Connection = Connect
 
-# we include a doctored version_info here for MySQLdb compatibility
-version_info = (1,2,2,"final",0)
-
 NULL = "NULL"
 
-__version__ = get_client_info()
-
-def thread_safe():
-    return True # match MySQLdb.thread_safe()
-
-def install_as_MySQLdb():
-    """
-    After this function is called, any application that imports MySQLdb or
-    _mysql will unwittingly actually use 
-    """
-    sys.modules["MySQLdb"] = sys.modules["_mysql"] = sys.modules["cymysql"]
+__version__ = '%s.%s.%s' % VERSION
 
 __all__ = [
     'BINARY', 'Binary', 'Connect', 'Connection', 'DATE', 'Date',
@@ -119,11 +103,6 @@ __all__ = [
     'InterfaceError', 'InternalError', 'MySQLError', 'NULL', 'NUMBER',
     'NotSupportedError', 'DBAPISet', 'OperationalError', 'ProgrammingError',
     'ROWID', 'STRING', 'TIME', 'TIMESTAMP', 'Warning', 'apilevel', 'connect',
-    'constants', 'converters', 'cursors',
-    'escape_dict', 'escape_sequence', 'escape_string', 'get_client_info',
-    'paramstyle', 'threadsafety', 'version_info',
-
-    "install_as_MySQLdb",
-
-    "NULL","__version__",
+    'constants', 'converters', 'cursors', 'escape_dict', 'escape_sequence',
+    'escape_string', 'paramstyle', 'threadsafety', "NULL","__version__",
     ]
